# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .action import Action
from .action_details import ActionDetails
from .action_details_list import ActionDetailsList
from .action_list import ActionList
from .change_rule_compartment_details import ChangeRuleCompartmentDetails
from .create_faa_s_action_details import CreateFaaSActionDetails
from .create_notification_service_action_details import CreateNotificationServiceActionDetails
from .create_rule_details import CreateRuleDetails
from .create_streaming_service_action_details import CreateStreamingServiceActionDetails
from .faa_s_action import FaaSAction
from .notification_service_action import NotificationServiceAction
from .rule import Rule
from .rule_summary import RuleSummary
from .streaming_service_action import StreamingServiceAction
from .update_rule_details import UpdateRuleDetails

# Maps type names to classes for events services.
events_type_mapping = {
    "Action": Action,
    "ActionDetails": ActionDetails,
    "ActionDetailsList": ActionDetailsList,
    "ActionList": ActionList,
    "ChangeRuleCompartmentDetails": ChangeRuleCompartmentDetails,
    "CreateFaaSActionDetails": CreateFaaSActionDetails,
    "CreateNotificationServiceActionDetails": CreateNotificationServiceActionDetails,
    "CreateRuleDetails": CreateRuleDetails,
    "CreateStreamingServiceActionDetails": CreateStreamingServiceActionDetails,
    "FaaSAction": FaaSAction,
    "NotificationServiceAction": NotificationServiceAction,
    "Rule": Rule,
    "RuleSummary": RuleSummary,
    "StreamingServiceAction": StreamingServiceAction,
    "UpdateRuleDetails": UpdateRuleDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateNetworkSourceDetails(object):
    """
    Properties for creating a network source object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateNetworkSourceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateNetworkSourceDetails.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this CreateNetworkSourceDetails.
        :type name: str

        :param public_source_list:
            The value to assign to the public_source_list property of this CreateNetworkSourceDetails.
        :type public_source_list: list[str]

        :param virtual_source_list:
            The value to assign to the virtual_source_list property of this CreateNetworkSourceDetails.
        :type virtual_source_list: list[oci.identity.models.NetworkSourcesVirtualSourceList]

        :param services:
            The value to assign to the services property of this CreateNetworkSourceDetails.
        :type services: list[str]

        :param description:
            The value to assign to the description property of this CreateNetworkSourceDetails.
        :type description: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateNetworkSourceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateNetworkSourceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'name': 'str',
            'public_source_list': 'list[str]',
            'virtual_source_list': 'list[NetworkSourcesVirtualSourceList]',
            'services': 'list[str]',
            'description': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'name': 'name',
            'public_source_list': 'publicSourceList',
            'virtual_source_list': 'virtualSourceList',
            'services': 'services',
            'description': 'description',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._name = None
        self._public_source_list = None
        self._virtual_source_list = None
        self._services = None
        self._description = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateNetworkSourceDetails.
        The OCID of the tenancy (root compartment) containing the network source object.


        :return: The compartment_id of this CreateNetworkSourceDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateNetworkSourceDetails.
        The OCID of the tenancy (root compartment) containing the network source object.


        :param compartment_id: The compartment_id of this CreateNetworkSourceDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateNetworkSourceDetails.
        The name you assign to the network source during creation. The name must be unique across all groups
        in the tenancy and cannot be changed.


        :return: The name of this CreateNetworkSourceDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateNetworkSourceDetails.
        The name you assign to the network source during creation. The name must be unique across all groups
        in the tenancy and cannot be changed.


        :param name: The name of this CreateNetworkSourceDetails.
        :type: str
        """
        self._name = name

    @property
    def public_source_list(self):
        """
        Gets the public_source_list of this CreateNetworkSourceDetails.
        A list of allowed public IP addresses and CIDR ranges.


        :return: The public_source_list of this CreateNetworkSourceDetails.
        :rtype: list[str]
        """
        return self._public_source_list

    @public_source_list.setter
    def public_source_list(self, public_source_list):
        """
        Sets the public_source_list of this CreateNetworkSourceDetails.
        A list of allowed public IP addresses and CIDR ranges.


        :param public_source_list: The public_source_list of this CreateNetworkSourceDetails.
        :type: list[str]
        """
        self._public_source_list = public_source_list

    @property
    def virtual_source_list(self):
        """
        Gets the virtual_source_list of this CreateNetworkSourceDetails.
        A list of allowed VCN OCID and IP range pairs.
        Example:`\"vcnId\": \"ocid1.vcn.oc1.iad.aaaaaaaaexampleuniqueID\", \"ipRanges\": [ \"129.213.39.0/24\" ]`


        :return: The virtual_source_list of this CreateNetworkSourceDetails.
        :rtype: list[oci.identity.models.NetworkSourcesVirtualSourceList]
        """
        return self._virtual_source_list

    @virtual_source_list.setter
    def virtual_source_list(self, virtual_source_list):
        """
        Sets the virtual_source_list of this CreateNetworkSourceDetails.
        A list of allowed VCN OCID and IP range pairs.
        Example:`\"vcnId\": \"ocid1.vcn.oc1.iad.aaaaaaaaexampleuniqueID\", \"ipRanges\": [ \"129.213.39.0/24\" ]`


        :param virtual_source_list: The virtual_source_list of this CreateNetworkSourceDetails.
        :type: list[oci.identity.models.NetworkSourcesVirtualSourceList]
        """
        self._virtual_source_list = virtual_source_list

    @property
    def services(self):
        """
        Gets the services of this CreateNetworkSourceDetails.
        A list of services allowed to make on-behalf-of requests. These requests can have different source IP addresses
        than those listed in the network source.
        Currently, only `all` and `none` are supported. The default is `all`.


        :return: The services of this CreateNetworkSourceDetails.
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """
        Sets the services of this CreateNetworkSourceDetails.
        A list of services allowed to make on-behalf-of requests. These requests can have different source IP addresses
        than those listed in the network source.
        Currently, only `all` and `none` are supported. The default is `all`.


        :param services: The services of this CreateNetworkSourceDetails.
        :type: list[str]
        """
        self._services = services

    @property
    def description(self):
        """
        **[Required]** Gets the description of this CreateNetworkSourceDetails.
        The description you assign to the network source during creation. Does not have to be unique, and it's changeable.


        :return: The description of this CreateNetworkSourceDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateNetworkSourceDetails.
        The description you assign to the network source during creation. Does not have to be unique, and it's changeable.


        :param description: The description of this CreateNetworkSourceDetails.
        :type: str
        """
        self._description = description

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateNetworkSourceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateNetworkSourceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateNetworkSourceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateNetworkSourceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateNetworkSourceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateNetworkSourceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateNetworkSourceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateNetworkSourceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TargetResourceDetails(object):
    """
    Details about a bastion session's target resource.
    """

    #: A constant which can be used with the session_type property of a TargetResourceDetails.
    #: This constant has a value of "MANAGED_SSH"
    SESSION_TYPE_MANAGED_SSH = "MANAGED_SSH"

    #: A constant which can be used with the session_type property of a TargetResourceDetails.
    #: This constant has a value of "PORT_FORWARDING"
    SESSION_TYPE_PORT_FORWARDING = "PORT_FORWARDING"

    def __init__(self, **kwargs):
        """
        Initializes a new TargetResourceDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.bastion.models.ManagedSshSessionTargetResourceDetails`
        * :class:`~oci.bastion.models.PortForwardingSessionTargetResourceDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param session_type:
            The value to assign to the session_type property of this TargetResourceDetails.
            Allowed values for this property are: "MANAGED_SSH", "PORT_FORWARDING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type session_type: str

        :param target_resource_port:
            The value to assign to the target_resource_port property of this TargetResourceDetails.
        :type target_resource_port: int

        """
        self.swagger_types = {
            'session_type': 'str',
            'target_resource_port': 'int'
        }

        self.attribute_map = {
            'session_type': 'sessionType',
            'target_resource_port': 'targetResourcePort'
        }

        self._session_type = None
        self._target_resource_port = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['sessionType']

        if type == 'MANAGED_SSH':
            return 'ManagedSshSessionTargetResourceDetails'

        if type == 'PORT_FORWARDING':
            return 'PortForwardingSessionTargetResourceDetails'
        else:
            return 'TargetResourceDetails'

    @property
    def session_type(self):
        """
        **[Required]** Gets the session_type of this TargetResourceDetails.
        The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.

        Allowed values for this property are: "MANAGED_SSH", "PORT_FORWARDING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The session_type of this TargetResourceDetails.
        :rtype: str
        """
        return self._session_type

    @session_type.setter
    def session_type(self, session_type):
        """
        Sets the session_type of this TargetResourceDetails.
        The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.


        :param session_type: The session_type of this TargetResourceDetails.
        :type: str
        """
        allowed_values = ["MANAGED_SSH", "PORT_FORWARDING"]
        if not value_allowed_none_or_none_sentinel(session_type, allowed_values):
            session_type = 'UNKNOWN_ENUM_VALUE'
        self._session_type = session_type

    @property
    def target_resource_port(self):
        """
        **[Required]** Gets the target_resource_port of this TargetResourceDetails.
        The port number to connect to on the target resource.


        :return: The target_resource_port of this TargetResourceDetails.
        :rtype: int
        """
        return self._target_resource_port

    @target_resource_port.setter
    def target_resource_port(self, target_resource_port):
        """
        Sets the target_resource_port of this TargetResourceDetails.
        The port number to connect to on the target resource.


        :param target_resource_port: The target_resource_port of this TargetResourceDetails.
        :type: int
        """
        self._target_resource_port = target_resource_port

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CapacityReservationInstanceSummary(object):
    """
    Condensed instance data when listing instances in a compute capacity reservation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CapacityReservationInstanceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CapacityReservationInstanceSummary.
        :type id: str

        :param availability_domain:
            The value to assign to the availability_domain property of this CapacityReservationInstanceSummary.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CapacityReservationInstanceSummary.
        :type compartment_id: str

        :param fault_domain:
            The value to assign to the fault_domain property of this CapacityReservationInstanceSummary.
        :type fault_domain: str

        :param shape_config:
            The value to assign to the shape_config property of this CapacityReservationInstanceSummary.
        :type shape_config: oci.core.models.InstanceReservationShapeConfigDetails

        :param shape:
            The value to assign to the shape property of this CapacityReservationInstanceSummary.
        :type shape: str

        """
        self.swagger_types = {
            'id': 'str',
            'availability_domain': 'str',
            'compartment_id': 'str',
            'fault_domain': 'str',
            'shape_config': 'InstanceReservationShapeConfigDetails',
            'shape': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'fault_domain': 'faultDomain',
            'shape_config': 'shapeConfig',
            'shape': 'shape'
        }

        self._id = None
        self._availability_domain = None
        self._compartment_id = None
        self._fault_domain = None
        self._shape_config = None
        self._shape = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CapacityReservationInstanceSummary.
        The OCID of the instance.


        :return: The id of this CapacityReservationInstanceSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CapacityReservationInstanceSummary.
        The OCID of the instance.


        :param id: The id of this CapacityReservationInstanceSummary.
        :type: str
        """
        self._id = id

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CapacityReservationInstanceSummary.
        The availability domain the instance is running in.


        :return: The availability_domain of this CapacityReservationInstanceSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CapacityReservationInstanceSummary.
        The availability domain the instance is running in.


        :param availability_domain: The availability_domain of this CapacityReservationInstanceSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CapacityReservationInstanceSummary.
        The OCID of the compartment that contains the instance.


        :return: The compartment_id of this CapacityReservationInstanceSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CapacityReservationInstanceSummary.
        The OCID of the compartment that contains the instance.


        :param compartment_id: The compartment_id of this CapacityReservationInstanceSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this CapacityReservationInstanceSummary.
        The fault domain the instance is running in.


        :return: The fault_domain of this CapacityReservationInstanceSummary.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this CapacityReservationInstanceSummary.
        The fault domain the instance is running in.


        :param fault_domain: The fault_domain of this CapacityReservationInstanceSummary.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def shape_config(self):
        """
        Gets the shape_config of this CapacityReservationInstanceSummary.

        :return: The shape_config of this CapacityReservationInstanceSummary.
        :rtype: oci.core.models.InstanceReservationShapeConfigDetails
        """
        return self._shape_config

    @shape_config.setter
    def shape_config(self, shape_config):
        """
        Sets the shape_config of this CapacityReservationInstanceSummary.

        :param shape_config: The shape_config of this CapacityReservationInstanceSummary.
        :type: oci.core.models.InstanceReservationShapeConfigDetails
        """
        self._shape_config = shape_config

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this CapacityReservationInstanceSummary.
        The shape of the instance. The shape determines the number of CPUs, amount of memory,
        and other resources allocated to the instance.

        You can enumerate all available shapes by calling :func:`list_compute_capacity_reservation_instance_shapes`.


        :return: The shape of this CapacityReservationInstanceSummary.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this CapacityReservationInstanceSummary.
        The shape of the instance. The shape determines the number of CPUs, amount of memory,
        and other resources allocated to the instance.

        You can enumerate all available shapes by calling :func:`list_compute_capacity_reservation_instance_shapes`.


        :param shape: The shape of this CapacityReservationInstanceSummary.
        :type: str
        """
        self._shape = shape

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_performance_metric_group import HostPerformanceMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostMemoryUsage(HostPerformanceMetricGroup):
    """
    Memory usage metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostMemoryUsage object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostMemoryUsage.metric_name` attribute
        of this class is ``HOST_MEMORY_USAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostMemoryUsage.
            Allowed values for this property are: "HOST_CPU_USAGE", "HOST_MEMORY_USAGE", "HOST_NETWORK_ACTIVITY_SUMMARY"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostMemoryUsage.
        :type time_collected: datetime

        :param memory_used_in_gb:
            The value to assign to the memory_used_in_gb property of this HostMemoryUsage.
        :type memory_used_in_gb: float

        :param memory_utilization_in_percent:
            The value to assign to the memory_utilization_in_percent property of this HostMemoryUsage.
        :type memory_utilization_in_percent: float

        :param memory_load_in_gb:
            The value to assign to the memory_load_in_gb property of this HostMemoryUsage.
        :type memory_load_in_gb: float

        :param real_memory_in_kb:
            The value to assign to the real_memory_in_kb property of this HostMemoryUsage.
        :type real_memory_in_kb: float

        :param free_memory_in_kb:
            The value to assign to the free_memory_in_kb property of this HostMemoryUsage.
        :type free_memory_in_kb: float

        :param logical_memory_used_in_gb:
            The value to assign to the logical_memory_used_in_gb property of this HostMemoryUsage.
        :type logical_memory_used_in_gb: float

        :param logical_memory_utilization_in_percent:
            The value to assign to the logical_memory_utilization_in_percent property of this HostMemoryUsage.
        :type logical_memory_utilization_in_percent: float

        :param free_logical_memory_in_kb:
            The value to assign to the free_logical_memory_in_kb property of this HostMemoryUsage.
        :type free_logical_memory_in_kb: float

        :param major_page_faults:
            The value to assign to the major_page_faults property of this HostMemoryUsage.
        :type major_page_faults: int

        :param swap_free_in_kb:
            The value to assign to the swap_free_in_kb property of this HostMemoryUsage.
        :type swap_free_in_kb: float

        :param anon_huge_pages_in_kb:
            The value to assign to the anon_huge_pages_in_kb property of this HostMemoryUsage.
        :type anon_huge_pages_in_kb: float

        :param huge_pages_free:
            The value to assign to the huge_pages_free property of this HostMemoryUsage.
        :type huge_pages_free: int

        :param huge_pages_reserved:
            The value to assign to the huge_pages_reserved property of this HostMemoryUsage.
        :type huge_pages_reserved: int

        :param huge_pages_surplus:
            The value to assign to the huge_pages_surplus property of this HostMemoryUsage.
        :type huge_pages_surplus: int

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'memory_used_in_gb': 'float',
            'memory_utilization_in_percent': 'float',
            'memory_load_in_gb': 'float',
            'real_memory_in_kb': 'float',
            'free_memory_in_kb': 'float',
            'logical_memory_used_in_gb': 'float',
            'logical_memory_utilization_in_percent': 'float',
            'free_logical_memory_in_kb': 'float',
            'major_page_faults': 'int',
            'swap_free_in_kb': 'float',
            'anon_huge_pages_in_kb': 'float',
            'huge_pages_free': 'int',
            'huge_pages_reserved': 'int',
            'huge_pages_surplus': 'int'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'memory_used_in_gb': 'memoryUsedInGB',
            'memory_utilization_in_percent': 'memoryUtilizationInPercent',
            'memory_load_in_gb': 'memoryLoadInGB',
            'real_memory_in_kb': 'realMemoryInKB',
            'free_memory_in_kb': 'freeMemoryInKB',
            'logical_memory_used_in_gb': 'logicalMemoryUsedInGB',
            'logical_memory_utilization_in_percent': 'logicalMemoryUtilizationInPercent',
            'free_logical_memory_in_kb': 'freeLogicalMemoryInKB',
            'major_page_faults': 'majorPageFaults',
            'swap_free_in_kb': 'swapFreeInKB',
            'anon_huge_pages_in_kb': 'anonHugePagesInKB',
            'huge_pages_free': 'hugePagesFree',
            'huge_pages_reserved': 'hugePagesReserved',
            'huge_pages_surplus': 'hugePagesSurplus'
        }

        self._metric_name = None
        self._time_collected = None
        self._memory_used_in_gb = None
        self._memory_utilization_in_percent = None
        self._memory_load_in_gb = None
        self._real_memory_in_kb = None
        self._free_memory_in_kb = None
        self._logical_memory_used_in_gb = None
        self._logical_memory_utilization_in_percent = None
        self._free_logical_memory_in_kb = None
        self._major_page_faults = None
        self._swap_free_in_kb = None
        self._anon_huge_pages_in_kb = None
        self._huge_pages_free = None
        self._huge_pages_reserved = None
        self._huge_pages_surplus = None
        self._metric_name = 'HOST_MEMORY_USAGE'

    @property
    def memory_used_in_gb(self):
        """
        Gets the memory_used_in_gb of this HostMemoryUsage.
        Amount of physical memory used in gigabytes


        :return: The memory_used_in_gb of this HostMemoryUsage.
        :rtype: float
        """
        return self._memory_used_in_gb

    @memory_used_in_gb.setter
    def memory_used_in_gb(self, memory_used_in_gb):
        """
        Sets the memory_used_in_gb of this HostMemoryUsage.
        Amount of physical memory used in gigabytes


        :param memory_used_in_gb: The memory_used_in_gb of this HostMemoryUsage.
        :type: float
        """
        self._memory_used_in_gb = memory_used_in_gb

    @property
    def memory_utilization_in_percent(self):
        """
        Gets the memory_utilization_in_percent of this HostMemoryUsage.
        Amount of physical memory used in percentage


        :return: The memory_utilization_in_percent of this HostMemoryUsage.
        :rtype: float
        """
        return self._memory_utilization_in_percent

    @memory_utilization_in_percent.setter
    def memory_utilization_in_percent(self, memory_utilization_in_percent):
        """
        Sets the memory_utilization_in_percent of this HostMemoryUsage.
        Amount of physical memory used in percentage


        :param memory_utilization_in_percent: The memory_utilization_in_percent of this HostMemoryUsage.
        :type: float
        """
        self._memory_utilization_in_percent = memory_utilization_in_percent

    @property
    def memory_load_in_gb(self):
        """
        Gets the memory_load_in_gb of this HostMemoryUsage.
        Load on memory in gigabytes


        :return: The memory_load_in_gb of this HostMemoryUsage.
        :rtype: float
        """
        return self._memory_load_in_gb

    @memory_load_in_gb.setter
    def memory_load_in_gb(self, memory_load_in_gb):
        """
        Sets the memory_load_in_gb of this HostMemoryUsage.
        Load on memory in gigabytes


        :param memory_load_in_gb: The memory_load_in_gb of this HostMemoryUsage.
        :type: float
        """
        self._memory_load_in_gb = memory_load_in_gb

    @property
    def real_memory_in_kb(self):
        """
        Gets the real_memory_in_kb of this HostMemoryUsage.
        Amount of usable physical memory in kilobytes


        :return: The real_memory_in_kb of this HostMemoryUsage.
        :rtype: float
        """
        return self._real_memory_in_kb

    @real_memory_in_kb.setter
    def real_memory_in_kb(self, real_memory_in_kb):
        """
        Sets the real_memory_in_kb of this HostMemoryUsage.
        Amount of usable physical memory in kilobytes


        :param real_memory_in_kb: The real_memory_in_kb of this HostMemoryUsage.
        :type: float
        """
        self._real_memory_in_kb = real_memory_in_kb

    @property
    def free_memory_in_kb(self):
        """
        Gets the free_memory_in_kb of this HostMemoryUsage.
        Amount of available physical memory in kilobytes


        :return: The free_memory_in_kb of this HostMemoryUsage.
        :rtype: float
        """
        return self._free_memory_in_kb

    @free_memory_in_kb.setter
    def free_memory_in_kb(self, free_memory_in_kb):
        """
        Sets the free_memory_in_kb of this HostMemoryUsage.
        Amount of available physical memory in kilobytes


        :param free_memory_in_kb: The free_memory_in_kb of this HostMemoryUsage.
        :type: float
        """
        self._free_memory_in_kb = free_memory_in_kb

    @property
    def logical_memory_used_in_gb(self):
        """
        Gets the logical_memory_used_in_gb of this HostMemoryUsage.
        Memory used excluding buffers and cache in gigabytes


        :return: The logical_memory_used_in_gb of this HostMemoryUsage.
        :rtype: float
        """
        return self._logical_memory_used_in_gb

    @logical_memory_used_in_gb.setter
    def logical_memory_used_in_gb(self, logical_memory_used_in_gb):
        """
        Sets the logical_memory_used_in_gb of this HostMemoryUsage.
        Memory used excluding buffers and cache in gigabytes


        :param logical_memory_used_in_gb: The logical_memory_used_in_gb of this HostMemoryUsage.
        :type: float
        """
        self._logical_memory_used_in_gb = logical_memory_used_in_gb

    @property
    def logical_memory_utilization_in_percent(self):
        """
        Gets the logical_memory_utilization_in_percent of this HostMemoryUsage.
        Amount of logical memory used in percentage


        :return: The logical_memory_utilization_in_percent of this HostMemoryUsage.
        :rtype: float
        """
        return self._logical_memory_utilization_in_percent

    @logical_memory_utilization_in_percent.setter
    def logical_memory_utilization_in_percent(self, logical_memory_utilization_in_percent):
        """
        Sets the logical_memory_utilization_in_percent of this HostMemoryUsage.
        Amount of logical memory used in percentage


        :param logical_memory_utilization_in_percent: The logical_memory_utilization_in_percent of this HostMemoryUsage.
        :type: float
        """
        self._logical_memory_utilization_in_percent = logical_memory_utilization_in_percent

    @property
    def free_logical_memory_in_kb(self):
        """
        Gets the free_logical_memory_in_kb of this HostMemoryUsage.
        Amount of avaiable virtual memory in kilobytes


        :return: The free_logical_memory_in_kb of this HostMemoryUsage.
        :rtype: float
        """
        return self._free_logical_memory_in_kb

    @free_logical_memory_in_kb.setter
    def free_logical_memory_in_kb(self, free_logical_memory_in_kb):
        """
        Sets the free_logical_memory_in_kb of this HostMemoryUsage.
        Amount of avaiable virtual memory in kilobytes


        :param free_logical_memory_in_kb: The free_logical_memory_in_kb of this HostMemoryUsage.
        :type: float
        """
        self._free_logical_memory_in_kb = free_logical_memory_in_kb

    @property
    def major_page_faults(self):
        """
        Gets the major_page_faults of this HostMemoryUsage.
        Number of major page faults


        :return: The major_page_faults of this HostMemoryUsage.
        :rtype: int
        """
        return self._major_page_faults

    @major_page_faults.setter
    def major_page_faults(self, major_page_faults):
        """
        Sets the major_page_faults of this HostMemoryUsage.
        Number of major page faults


        :param major_page_faults: The major_page_faults of this HostMemoryUsage.
        :type: int
        """
        self._major_page_faults = major_page_faults

    @property
    def swap_free_in_kb(self):
        """
        Gets the swap_free_in_kb of this HostMemoryUsage.
        Amount of available swap space in kilobytes


        :return: The swap_free_in_kb of this HostMemoryUsage.
        :rtype: float
        """
        return self._swap_free_in_kb

    @swap_free_in_kb.setter
    def swap_free_in_kb(self, swap_free_in_kb):
        """
        Sets the swap_free_in_kb of this HostMemoryUsage.
        Amount of available swap space in kilobytes


        :param swap_free_in_kb: The swap_free_in_kb of this HostMemoryUsage.
        :type: float
        """
        self._swap_free_in_kb = swap_free_in_kb

    @property
    def anon_huge_pages_in_kb(self):
        """
        Gets the anon_huge_pages_in_kb of this HostMemoryUsage.
        Amount of memory used for anon huge pages in kilobytes


        :return: The anon_huge_pages_in_kb of this HostMemoryUsage.
        :rtype: float
        """
        return self._anon_huge_pages_in_kb

    @anon_huge_pages_in_kb.setter
    def anon_huge_pages_in_kb(self, anon_huge_pages_in_kb):
        """
        Sets the anon_huge_pages_in_kb of this HostMemoryUsage.
        Amount of memory used for anon huge pages in kilobytes


        :param anon_huge_pages_in_kb: The anon_huge_pages_in_kb of this HostMemoryUsage.
        :type: float
        """
        self._anon_huge_pages_in_kb = anon_huge_pages_in_kb

    @property
    def huge_pages_free(self):
        """
        Gets the huge_pages_free of this HostMemoryUsage.
        Number of available huge pages


        :return: The huge_pages_free of this HostMemoryUsage.
        :rtype: int
        """
        return self._huge_pages_free

    @huge_pages_free.setter
    def huge_pages_free(self, huge_pages_free):
        """
        Sets the huge_pages_free of this HostMemoryUsage.
        Number of available huge pages


        :param huge_pages_free: The huge_pages_free of this HostMemoryUsage.
        :type: int
        """
        self._huge_pages_free = huge_pages_free

    @property
    def huge_pages_reserved(self):
        """
        Gets the huge_pages_reserved of this HostMemoryUsage.
        Number of reserved huge pages


        :return: The huge_pages_reserved of this HostMemoryUsage.
        :rtype: int
        """
        return self._huge_pages_reserved

    @huge_pages_reserved.setter
    def huge_pages_reserved(self, huge_pages_reserved):
        """
        Sets the huge_pages_reserved of this HostMemoryUsage.
        Number of reserved huge pages


        :param huge_pages_reserved: The huge_pages_reserved of this HostMemoryUsage.
        :type: int
        """
        self._huge_pages_reserved = huge_pages_reserved

    @property
    def huge_pages_surplus(self):
        """
        Gets the huge_pages_surplus of this HostMemoryUsage.
        Number of surplus huge pages


        :return: The huge_pages_surplus of this HostMemoryUsage.
        :rtype: int
        """
        return self._huge_pages_surplus

    @huge_pages_surplus.setter
    def huge_pages_surplus(self, huge_pages_surplus):
        """
        Sets the huge_pages_surplus of this HostMemoryUsage.
        Number of surplus huge pages


        :param huge_pages_surplus: The huge_pages_surplus of this HostMemoryUsage.
        :type: int
        """
        self._huge_pages_surplus = huge_pages_surplus

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsParameter(object):
    """
    LogAnalyticsParameter
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsParameter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param default_value:
            The value to assign to the default_value property of this LogAnalyticsParameter.
        :type default_value: str

        :param description:
            The value to assign to the description property of this LogAnalyticsParameter.
        :type description: str

        :param is_active:
            The value to assign to the is_active property of this LogAnalyticsParameter.
        :type is_active: bool

        :param name:
            The value to assign to the name property of this LogAnalyticsParameter.
        :type name: str

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsParameter.
        :type source_id: int

        """
        self.swagger_types = {
            'default_value': 'str',
            'description': 'str',
            'is_active': 'bool',
            'name': 'str',
            'source_id': 'int'
        }

        self.attribute_map = {
            'default_value': 'defaultValue',
            'description': 'description',
            'is_active': 'isActive',
            'name': 'name',
            'source_id': 'sourceId'
        }

        self._default_value = None
        self._description = None
        self._is_active = None
        self._name = None
        self._source_id = None

    @property
    def default_value(self):
        """
        Gets the default_value of this LogAnalyticsParameter.
        The default value of the parameter.


        :return: The default_value of this LogAnalyticsParameter.
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this LogAnalyticsParameter.
        The default value of the parameter.


        :param default_value: The default_value of this LogAnalyticsParameter.
        :type: str
        """
        self._default_value = default_value

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsParameter.
        The parameter description.


        :return: The description of this LogAnalyticsParameter.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsParameter.
        The parameter description.


        :param description: The description of this LogAnalyticsParameter.
        :type: str
        """
        self._description = description

    @property
    def is_active(self):
        """
        Gets the is_active of this LogAnalyticsParameter.
        A flag indicating whether or not the parameter is active.


        :return: The is_active of this LogAnalyticsParameter.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this LogAnalyticsParameter.
        A flag indicating whether or not the parameter is active.


        :param is_active: The is_active of this LogAnalyticsParameter.
        :type: bool
        """
        self._is_active = is_active

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsParameter.
        The parameter name.


        :return: The name of this LogAnalyticsParameter.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsParameter.
        The parameter name.


        :param name: The name of this LogAnalyticsParameter.
        :type: str
        """
        self._name = name

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsParameter.
        The source unique identifier.


        :return: The source_id of this LogAnalyticsParameter.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsParameter.
        The source unique identifier.


        :param source_id: The source_id of this LogAnalyticsParameter.
        :type: int
        """
        self._source_id = source_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VmClusterUpdateHistoryEntrySummary(object):
    """
    The record of a maintenance update action performed on a specified VM cluster. Applies to Exadata Cloud@Customer instances only.
    """

    #: A constant which can be used with the update_action property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "ROLLING_APPLY"
    UPDATE_ACTION_ROLLING_APPLY = "ROLLING_APPLY"

    #: A constant which can be used with the update_action property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "PRECHECK"
    UPDATE_ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the update_action property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "ROLLBACK"
    UPDATE_ACTION_ROLLBACK = "ROLLBACK"

    #: A constant which can be used with the update_type property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "GI_UPGRADE"
    UPDATE_TYPE_GI_UPGRADE = "GI_UPGRADE"

    #: A constant which can be used with the update_type property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "GI_PATCH"
    UPDATE_TYPE_GI_PATCH = "GI_PATCH"

    #: A constant which can be used with the update_type property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "OS_UPDATE"
    UPDATE_TYPE_OS_UPDATE = "OS_UPDATE"

    #: A constant which can be used with the lifecycle_state property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a VmClusterUpdateHistoryEntrySummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new VmClusterUpdateHistoryEntrySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VmClusterUpdateHistoryEntrySummary.
        :type id: str

        :param update_id:
            The value to assign to the update_id property of this VmClusterUpdateHistoryEntrySummary.
        :type update_id: str

        :param update_action:
            The value to assign to the update_action property of this VmClusterUpdateHistoryEntrySummary.
            Allowed values for this property are: "ROLLING_APPLY", "PRECHECK", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type update_action: str

        :param update_type:
            The value to assign to the update_type property of this VmClusterUpdateHistoryEntrySummary.
            Allowed values for this property are: "GI_UPGRADE", "GI_PATCH", "OS_UPDATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type update_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VmClusterUpdateHistoryEntrySummary.
            Allowed values for this property are: "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this VmClusterUpdateHistoryEntrySummary.
        :type lifecycle_details: str

        :param time_started:
            The value to assign to the time_started property of this VmClusterUpdateHistoryEntrySummary.
        :type time_started: datetime

        :param time_completed:
            The value to assign to the time_completed property of this VmClusterUpdateHistoryEntrySummary.
        :type time_completed: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'update_id': 'str',
            'update_action': 'str',
            'update_type': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_started': 'datetime',
            'time_completed': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'update_id': 'updateId',
            'update_action': 'updateAction',
            'update_type': 'updateType',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_started': 'timeStarted',
            'time_completed': 'timeCompleted'
        }

        self._id = None
        self._update_id = None
        self._update_action = None
        self._update_type = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_started = None
        self._time_completed = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VmClusterUpdateHistoryEntrySummary.
        The `OCID`__ of the maintenance update history entry.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this VmClusterUpdateHistoryEntrySummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VmClusterUpdateHistoryEntrySummary.
        The `OCID`__ of the maintenance update history entry.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this VmClusterUpdateHistoryEntrySummary.
        :type: str
        """
        self._id = id

    @property
    def update_id(self):
        """
        **[Required]** Gets the update_id of this VmClusterUpdateHistoryEntrySummary.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The update_id of this VmClusterUpdateHistoryEntrySummary.
        :rtype: str
        """
        return self._update_id

    @update_id.setter
    def update_id(self, update_id):
        """
        Sets the update_id of this VmClusterUpdateHistoryEntrySummary.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param update_id: The update_id of this VmClusterUpdateHistoryEntrySummary.
        :type: str
        """
        self._update_id = update_id

    @property
    def update_action(self):
        """
        Gets the update_action of this VmClusterUpdateHistoryEntrySummary.
        The update action performed using this maintenance update.

        Allowed values for this property are: "ROLLING_APPLY", "PRECHECK", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The update_action of this VmClusterUpdateHistoryEntrySummary.
        :rtype: str
        """
        return self._update_action

    @update_action.setter
    def update_action(self, update_action):
        """
        Sets the update_action of this VmClusterUpdateHistoryEntrySummary.
        The update action performed using this maintenance update.


        :param update_action: The update_action of this VmClusterUpdateHistoryEntrySummary.
        :type: str
        """
        allowed_values = ["ROLLING_APPLY", "PRECHECK", "ROLLBACK"]
        if not value_allowed_none_or_none_sentinel(update_action, allowed_values):
            update_action = 'UNKNOWN_ENUM_VALUE'
        self._update_action = update_action

    @property
    def update_type(self):
        """
        **[Required]** Gets the update_type of this VmClusterUpdateHistoryEntrySummary.
        The type of VM cluster maintenance update.

        Allowed values for this property are: "GI_UPGRADE", "GI_PATCH", "OS_UPDATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The update_type of this VmClusterUpdateHistoryEntrySummary.
        :rtype: str
        """
        return self._update_type

    @update_type.setter
    def update_type(self, update_type):
        """
        Sets the update_type of this VmClusterUpdateHistoryEntrySummary.
        The type of VM cluster maintenance update.


        :param update_type: The update_type of this VmClusterUpdateHistoryEntrySummary.
        :type: str
        """
        allowed_values = ["GI_UPGRADE", "GI_PATCH", "OS_UPDATE"]
        if not value_allowed_none_or_none_sentinel(update_type, allowed_values):
            update_type = 'UNKNOWN_ENUM_VALUE'
        self._update_type = update_type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this VmClusterUpdateHistoryEntrySummary.
        The current lifecycle state of the maintenance update operation.

        Allowed values for this property are: "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VmClusterUpdateHistoryEntrySummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VmClusterUpdateHistoryEntrySummary.
        The current lifecycle state of the maintenance update operation.


        :param lifecycle_state: The lifecycle_state of this VmClusterUpdateHistoryEntrySummary.
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this VmClusterUpdateHistoryEntrySummary.
        Descriptive text providing additional details about the lifecycle state.


        :return: The lifecycle_details of this VmClusterUpdateHistoryEntrySummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this VmClusterUpdateHistoryEntrySummary.
        Descriptive text providing additional details about the lifecycle state.


        :param lifecycle_details: The lifecycle_details of this VmClusterUpdateHistoryEntrySummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this VmClusterUpdateHistoryEntrySummary.
        The date and time when the maintenance update action started.


        :return: The time_started of this VmClusterUpdateHistoryEntrySummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this VmClusterUpdateHistoryEntrySummary.
        The date and time when the maintenance update action started.


        :param time_started: The time_started of this VmClusterUpdateHistoryEntrySummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_completed(self):
        """
        Gets the time_completed of this VmClusterUpdateHistoryEntrySummary.
        The date and time when the maintenance update action completed.


        :return: The time_completed of this VmClusterUpdateHistoryEntrySummary.
        :rtype: datetime
        """
        return self._time_completed

    @time_completed.setter
    def time_completed(self, time_completed):
        """
        Sets the time_completed of this VmClusterUpdateHistoryEntrySummary.
        The date and time when the maintenance update action completed.


        :param time_completed: The time_completed of this VmClusterUpdateHistoryEntrySummary.
        :type: datetime
        """
        self._time_completed = time_completed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDatabaseFromAnotherDatabaseDetails(object):
    """
    CreateDatabaseFromAnotherDatabaseDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDatabaseFromAnotherDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_id:
            The value to assign to the database_id property of this CreateDatabaseFromAnotherDatabaseDetails.
        :type database_id: str

        :param backup_tde_password:
            The value to assign to the backup_tde_password property of this CreateDatabaseFromAnotherDatabaseDetails.
        :type backup_tde_password: str

        :param admin_password:
            The value to assign to the admin_password property of this CreateDatabaseFromAnotherDatabaseDetails.
        :type admin_password: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this CreateDatabaseFromAnotherDatabaseDetails.
        :type db_unique_name: str

        :param db_name:
            The value to assign to the db_name property of this CreateDatabaseFromAnotherDatabaseDetails.
        :type db_name: str

        :param time_stamp_for_point_in_time_recovery:
            The value to assign to the time_stamp_for_point_in_time_recovery property of this CreateDatabaseFromAnotherDatabaseDetails.
        :type time_stamp_for_point_in_time_recovery: datetime

        """
        self.swagger_types = {
            'database_id': 'str',
            'backup_tde_password': 'str',
            'admin_password': 'str',
            'db_unique_name': 'str',
            'db_name': 'str',
            'time_stamp_for_point_in_time_recovery': 'datetime'
        }

        self.attribute_map = {
            'database_id': 'databaseId',
            'backup_tde_password': 'backupTDEPassword',
            'admin_password': 'adminPassword',
            'db_unique_name': 'dbUniqueName',
            'db_name': 'dbName',
            'time_stamp_for_point_in_time_recovery': 'timeStampForPointInTimeRecovery'
        }

        self._database_id = None
        self._backup_tde_password = None
        self._admin_password = None
        self._db_unique_name = None
        self._db_name = None
        self._time_stamp_for_point_in_time_recovery = None

    @property
    def database_id(self):
        """
        **[Required]** Gets the database_id of this CreateDatabaseFromAnotherDatabaseDetails.
        The database `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_id of this CreateDatabaseFromAnotherDatabaseDetails.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this CreateDatabaseFromAnotherDatabaseDetails.
        The database `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this CreateDatabaseFromAnotherDatabaseDetails.
        :type: str
        """
        self._database_id = database_id

    @property
    def backup_tde_password(self):
        """
        **[Required]** Gets the backup_tde_password of this CreateDatabaseFromAnotherDatabaseDetails.
        The password to open the TDE wallet.


        :return: The backup_tde_password of this CreateDatabaseFromAnotherDatabaseDetails.
        :rtype: str
        """
        return self._backup_tde_password

    @backup_tde_password.setter
    def backup_tde_password(self, backup_tde_password):
        """
        Sets the backup_tde_password of this CreateDatabaseFromAnotherDatabaseDetails.
        The password to open the TDE wallet.


        :param backup_tde_password: The backup_tde_password of this CreateDatabaseFromAnotherDatabaseDetails.
        :type: str
        """
        self._backup_tde_password = backup_tde_password

    @property
    def admin_password(self):
        """
        **[Required]** Gets the admin_password of this CreateDatabaseFromAnotherDatabaseDetails.
        A strong password for SYS, SYSTEM, PDB Admin and TDE Wallet. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :return: The admin_password of this CreateDatabaseFromAnotherDatabaseDetails.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this CreateDatabaseFromAnotherDatabaseDetails.
        A strong password for SYS, SYSTEM, PDB Admin and TDE Wallet. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :param admin_password: The admin_password of this CreateDatabaseFromAnotherDatabaseDetails.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this CreateDatabaseFromAnotherDatabaseDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :return: The db_unique_name of this CreateDatabaseFromAnotherDatabaseDetails.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this CreateDatabaseFromAnotherDatabaseDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :param db_unique_name: The db_unique_name of this CreateDatabaseFromAnotherDatabaseDetails.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def db_name(self):
        """
        Gets the db_name of this CreateDatabaseFromAnotherDatabaseDetails.
        The display name of the database to be created from the backup. It must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.


        :return: The db_name of this CreateDatabaseFromAnotherDatabaseDetails.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this CreateDatabaseFromAnotherDatabaseDetails.
        The display name of the database to be created from the backup. It must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.


        :param db_name: The db_name of this CreateDatabaseFromAnotherDatabaseDetails.
        :type: str
        """
        self._db_name = db_name

    @property
    def time_stamp_for_point_in_time_recovery(self):
        """
        Gets the time_stamp_for_point_in_time_recovery of this CreateDatabaseFromAnotherDatabaseDetails.
        The point in time of the original database from which the new database is created. If not specifed, the latest backup is used to create the database.


        :return: The time_stamp_for_point_in_time_recovery of this CreateDatabaseFromAnotherDatabaseDetails.
        :rtype: datetime
        """
        return self._time_stamp_for_point_in_time_recovery

    @time_stamp_for_point_in_time_recovery.setter
    def time_stamp_for_point_in_time_recovery(self, time_stamp_for_point_in_time_recovery):
        """
        Sets the time_stamp_for_point_in_time_recovery of this CreateDatabaseFromAnotherDatabaseDetails.
        The point in time of the original database from which the new database is created. If not specifed, the latest backup is used to create the database.


        :param time_stamp_for_point_in_time_recovery: The time_stamp_for_point_in_time_recovery of this CreateDatabaseFromAnotherDatabaseDetails.
        :type: datetime
        """
        self._time_stamp_for_point_in_time_recovery = time_stamp_for_point_in_time_recovery

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProjectedDataItem(object):
    """
    The timestamp of the projected event and their corresponding resource value.
    `highValue` and `lowValue` are the uncertainty bounds of the corresponding value.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProjectedDataItem object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param end_timestamp:
            The value to assign to the end_timestamp property of this ProjectedDataItem.
        :type end_timestamp: datetime

        :param usage:
            The value to assign to the usage property of this ProjectedDataItem.
        :type usage: float

        :param high_value:
            The value to assign to the high_value property of this ProjectedDataItem.
        :type high_value: float

        :param low_value:
            The value to assign to the low_value property of this ProjectedDataItem.
        :type low_value: float

        """
        self.swagger_types = {
            'end_timestamp': 'datetime',
            'usage': 'float',
            'high_value': 'float',
            'low_value': 'float'
        }

        self.attribute_map = {
            'end_timestamp': 'endTimestamp',
            'usage': 'usage',
            'high_value': 'highValue',
            'low_value': 'lowValue'
        }

        self._end_timestamp = None
        self._usage = None
        self._high_value = None
        self._low_value = None

    @property
    def end_timestamp(self):
        """
        **[Required]** Gets the end_timestamp of this ProjectedDataItem.
        The timestamp in which the current sampling period ends in RFC 3339 format.


        :return: The end_timestamp of this ProjectedDataItem.
        :rtype: datetime
        """
        return self._end_timestamp

    @end_timestamp.setter
    def end_timestamp(self, end_timestamp):
        """
        Sets the end_timestamp of this ProjectedDataItem.
        The timestamp in which the current sampling period ends in RFC 3339 format.


        :param end_timestamp: The end_timestamp of this ProjectedDataItem.
        :type: datetime
        """
        self._end_timestamp = end_timestamp

    @property
    def usage(self):
        """
        **[Required]** Gets the usage of this ProjectedDataItem.
        Total amount used of the resource metric type (CPU, STORAGE).


        :return: The usage of this ProjectedDataItem.
        :rtype: float
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """
        Sets the usage of this ProjectedDataItem.
        Total amount used of the resource metric type (CPU, STORAGE).


        :param usage: The usage of this ProjectedDataItem.
        :type: float
        """
        self._usage = usage

    @property
    def high_value(self):
        """
        **[Required]** Gets the high_value of this ProjectedDataItem.
        Upper uncertainty bound of the current usage value.


        :return: The high_value of this ProjectedDataItem.
        :rtype: float
        """
        return self._high_value

    @high_value.setter
    def high_value(self, high_value):
        """
        Sets the high_value of this ProjectedDataItem.
        Upper uncertainty bound of the current usage value.


        :param high_value: The high_value of this ProjectedDataItem.
        :type: float
        """
        self._high_value = high_value

    @property
    def low_value(self):
        """
        **[Required]** Gets the low_value of this ProjectedDataItem.
        Lower uncertainty bound of the current usage value.


        :return: The low_value of this ProjectedDataItem.
        :rtype: float
        """
        return self._low_value

    @low_value.setter
    def low_value(self, low_value):
        """
        Sets the low_value of this ProjectedDataItem.
        Lower uncertainty bound of the current usage value.


        :param low_value: The low_value of this ProjectedDataItem.
        :type: float
        """
        self._low_value = low_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsAssociationParameter(object):
    """
    LogAnalyticsAssociationParameter
    """

    #: A constant which can be used with the status property of a LogAnalyticsAssociationParameter.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a LogAnalyticsAssociationParameter.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsAssociationParameter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param agent_id:
            The value to assign to the agent_id property of this LogAnalyticsAssociationParameter.
        :type agent_id: str

        :param entity_type:
            The value to assign to the entity_type property of this LogAnalyticsAssociationParameter.
        :type entity_type: str

        :param entity_id:
            The value to assign to the entity_id property of this LogAnalyticsAssociationParameter.
        :type entity_id: str

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsAssociationParameter.
        :type source_id: str

        :param source_display_name:
            The value to assign to the source_display_name property of this LogAnalyticsAssociationParameter.
        :type source_display_name: str

        :param source_type:
            The value to assign to the source_type property of this LogAnalyticsAssociationParameter.
        :type source_type: str

        :param status:
            The value to assign to the status property of this LogAnalyticsAssociationParameter.
            Allowed values for this property are: "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param missing_properties:
            The value to assign to the missing_properties property of this LogAnalyticsAssociationParameter.
        :type missing_properties: list[str]

        :param required_properties:
            The value to assign to the required_properties property of this LogAnalyticsAssociationParameter.
        :type required_properties: list[str]

        """
        self.swagger_types = {
            'agent_id': 'str',
            'entity_type': 'str',
            'entity_id': 'str',
            'source_id': 'str',
            'source_display_name': 'str',
            'source_type': 'str',
            'status': 'str',
            'missing_properties': 'list[str]',
            'required_properties': 'list[str]'
        }

        self.attribute_map = {
            'agent_id': 'agentId',
            'entity_type': 'entityType',
            'entity_id': 'entityId',
            'source_id': 'sourceId',
            'source_display_name': 'sourceDisplayName',
            'source_type': 'sourceType',
            'status': 'status',
            'missing_properties': 'missingProperties',
            'required_properties': 'requiredProperties'
        }

        self._agent_id = None
        self._entity_type = None
        self._entity_id = None
        self._source_id = None
        self._source_display_name = None
        self._source_type = None
        self._status = None
        self._missing_properties = None
        self._required_properties = None

    @property
    def agent_id(self):
        """
        Gets the agent_id of this LogAnalyticsAssociationParameter.
        The agent unique identifier.


        :return: The agent_id of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this LogAnalyticsAssociationParameter.
        The agent unique identifier.


        :param agent_id: The agent_id of this LogAnalyticsAssociationParameter.
        :type: str
        """
        self._agent_id = agent_id

    @property
    def entity_type(self):
        """
        Gets the entity_type of this LogAnalyticsAssociationParameter.
        The entity type.


        :return: The entity_type of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this LogAnalyticsAssociationParameter.
        The entity type.


        :param entity_type: The entity_type of this LogAnalyticsAssociationParameter.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def entity_id(self):
        """
        Gets the entity_id of this LogAnalyticsAssociationParameter.
        The entity unique identifier.


        :return: The entity_id of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this LogAnalyticsAssociationParameter.
        The entity unique identifier.


        :param entity_id: The entity_id of this LogAnalyticsAssociationParameter.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsAssociationParameter.
        The source name.


        :return: The source_id of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsAssociationParameter.
        The source name.


        :param source_id: The source_id of this LogAnalyticsAssociationParameter.
        :type: str
        """
        self._source_id = source_id

    @property
    def source_display_name(self):
        """
        Gets the source_display_name of this LogAnalyticsAssociationParameter.
        The source display name.


        :return: The source_display_name of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._source_display_name

    @source_display_name.setter
    def source_display_name(self, source_display_name):
        """
        Sets the source_display_name of this LogAnalyticsAssociationParameter.
        The source display name.


        :param source_display_name: The source_display_name of this LogAnalyticsAssociationParameter.
        :type: str
        """
        self._source_display_name = source_display_name

    @property
    def source_type(self):
        """
        Gets the source_type of this LogAnalyticsAssociationParameter.
        The source type.


        :return: The source_type of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """
        Sets the source_type of this LogAnalyticsAssociationParameter.
        The source type.


        :param source_type: The source_type of this LogAnalyticsAssociationParameter.
        :type: str
        """
        self._source_type = source_type

    @property
    def status(self):
        """
        Gets the status of this LogAnalyticsAssociationParameter.
        The status.  Either FAILED or SUCCEEDED.

        Allowed values for this property are: "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this LogAnalyticsAssociationParameter.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this LogAnalyticsAssociationParameter.
        The status.  Either FAILED or SUCCEEDED.


        :param status: The status of this LogAnalyticsAssociationParameter.
        :type: str
        """
        allowed_values = ["SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def missing_properties(self):
        """
        Gets the missing_properties of this LogAnalyticsAssociationParameter.
        A list of missing properties.


        :return: The missing_properties of this LogAnalyticsAssociationParameter.
        :rtype: list[str]
        """
        return self._missing_properties

    @missing_properties.setter
    def missing_properties(self, missing_properties):
        """
        Sets the missing_properties of this LogAnalyticsAssociationParameter.
        A list of missing properties.


        :param missing_properties: The missing_properties of this LogAnalyticsAssociationParameter.
        :type: list[str]
        """
        self._missing_properties = missing_properties

    @property
    def required_properties(self):
        """
        Gets the required_properties of this LogAnalyticsAssociationParameter.
        A list of requried properties.


        :return: The required_properties of this LogAnalyticsAssociationParameter.
        :rtype: list[str]
        """
        return self._required_properties

    @required_properties.setter
    def required_properties(self, required_properties):
        """
        Sets the required_properties of this LogAnalyticsAssociationParameter.
        A list of requried properties.


        :param required_properties: The required_properties of this LogAnalyticsAssociationParameter.
        :type: list[str]
        """
        self._required_properties = required_properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceConfiguration(object):
    """
    Properties related to a resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param spark_version:
            The value to assign to the spark_version property of this ResourceConfiguration.
        :type spark_version: str

        :param driver_shape:
            The value to assign to the driver_shape property of this ResourceConfiguration.
        :type driver_shape: str

        :param executor_shape:
            The value to assign to the executor_shape property of this ResourceConfiguration.
        :type executor_shape: str

        :param total_executors:
            The value to assign to the total_executors property of this ResourceConfiguration.
        :type total_executors: int

        """
        self.swagger_types = {
            'spark_version': 'str',
            'driver_shape': 'str',
            'executor_shape': 'str',
            'total_executors': 'int'
        }

        self.attribute_map = {
            'spark_version': 'sparkVersion',
            'driver_shape': 'driverShape',
            'executor_shape': 'executorShape',
            'total_executors': 'totalExecutors'
        }

        self._spark_version = None
        self._driver_shape = None
        self._executor_shape = None
        self._total_executors = None

    @property
    def spark_version(self):
        """
        **[Required]** Gets the spark_version of this ResourceConfiguration.
        The version of the spark used while creating an Oracle Cloud Infrastructure Data Flow application.


        :return: The spark_version of this ResourceConfiguration.
        :rtype: str
        """
        return self._spark_version

    @spark_version.setter
    def spark_version(self, spark_version):
        """
        Sets the spark_version of this ResourceConfiguration.
        The version of the spark used while creating an Oracle Cloud Infrastructure Data Flow application.


        :param spark_version: The spark_version of this ResourceConfiguration.
        :type: str
        """
        self._spark_version = spark_version

    @property
    def driver_shape(self):
        """
        **[Required]** Gets the driver_shape of this ResourceConfiguration.
        The VM shape of the driver used while creating an Oracle Cloud Infrastructure Data Flow application. It sets the driver cores and memory.


        :return: The driver_shape of this ResourceConfiguration.
        :rtype: str
        """
        return self._driver_shape

    @driver_shape.setter
    def driver_shape(self, driver_shape):
        """
        Sets the driver_shape of this ResourceConfiguration.
        The VM shape of the driver used while creating an Oracle Cloud Infrastructure Data Flow application. It sets the driver cores and memory.


        :param driver_shape: The driver_shape of this ResourceConfiguration.
        :type: str
        """
        self._driver_shape = driver_shape

    @property
    def executor_shape(self):
        """
        **[Required]** Gets the executor_shape of this ResourceConfiguration.
        The shape of the executor used while creating an Oracle Cloud Infrastructure Data Flow application. It sets the executor cores and memory.


        :return: The executor_shape of this ResourceConfiguration.
        :rtype: str
        """
        return self._executor_shape

    @executor_shape.setter
    def executor_shape(self, executor_shape):
        """
        Sets the executor_shape of this ResourceConfiguration.
        The shape of the executor used while creating an Oracle Cloud Infrastructure Data Flow application. It sets the executor cores and memory.


        :param executor_shape: The executor_shape of this ResourceConfiguration.
        :type: str
        """
        self._executor_shape = executor_shape

    @property
    def total_executors(self):
        """
        **[Required]** Gets the total_executors of this ResourceConfiguration.
        Number of executor VMs requested while creating an Oracle Cloud Infrastructure Data Flow application.


        :return: The total_executors of this ResourceConfiguration.
        :rtype: int
        """
        return self._total_executors

    @total_executors.setter
    def total_executors(self, total_executors):
        """
        Sets the total_executors of this ResourceConfiguration.
        Number of executor VMs requested while creating an Oracle Cloud Infrastructure Data Flow application.


        :param total_executors: The total_executors of this ResourceConfiguration.
        :type: int
        """
        self._total_executors = total_executors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterDetails(object):
    """
    Specific info about a Hadoop cluster
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param bda_version:
            The value to assign to the bda_version property of this ClusterDetails.
        :type bda_version: str

        :param bdm_version:
            The value to assign to the bdm_version property of this ClusterDetails.
        :type bdm_version: str

        :param bds_version:
            The value to assign to the bds_version property of this ClusterDetails.
        :type bds_version: str

        :param os_version:
            The value to assign to the os_version property of this ClusterDetails.
        :type os_version: str

        :param db_version:
            The value to assign to the db_version property of this ClusterDetails.
        :type db_version: str

        :param bd_cell_version:
            The value to assign to the bd_cell_version property of this ClusterDetails.
        :type bd_cell_version: str

        :param csql_cell_version:
            The value to assign to the csql_cell_version property of this ClusterDetails.
        :type csql_cell_version: str

        :param time_created:
            The value to assign to the time_created property of this ClusterDetails.
        :type time_created: datetime

        :param time_refreshed:
            The value to assign to the time_refreshed property of this ClusterDetails.
        :type time_refreshed: datetime

        :param cloudera_manager_url:
            The value to assign to the cloudera_manager_url property of this ClusterDetails.
        :type cloudera_manager_url: str

        :param ambari_url:
            The value to assign to the ambari_url property of this ClusterDetails.
        :type ambari_url: str

        :param big_data_manager_url:
            The value to assign to the big_data_manager_url property of this ClusterDetails.
        :type big_data_manager_url: str

        :param hue_server_url:
            The value to assign to the hue_server_url property of this ClusterDetails.
        :type hue_server_url: str

        """
        self.swagger_types = {
            'bda_version': 'str',
            'bdm_version': 'str',
            'bds_version': 'str',
            'os_version': 'str',
            'db_version': 'str',
            'bd_cell_version': 'str',
            'csql_cell_version': 'str',
            'time_created': 'datetime',
            'time_refreshed': 'datetime',
            'cloudera_manager_url': 'str',
            'ambari_url': 'str',
            'big_data_manager_url': 'str',
            'hue_server_url': 'str'
        }

        self.attribute_map = {
            'bda_version': 'bdaVersion',
            'bdm_version': 'bdmVersion',
            'bds_version': 'bdsVersion',
            'os_version': 'osVersion',
            'db_version': 'dbVersion',
            'bd_cell_version': 'bdCellVersion',
            'csql_cell_version': 'csqlCellVersion',
            'time_created': 'timeCreated',
            'time_refreshed': 'timeRefreshed',
            'cloudera_manager_url': 'clouderaManagerUrl',
            'ambari_url': 'ambariUrl',
            'big_data_manager_url': 'bigDataManagerUrl',
            'hue_server_url': 'hueServerUrl'
        }

        self._bda_version = None
        self._bdm_version = None
        self._bds_version = None
        self._os_version = None
        self._db_version = None
        self._bd_cell_version = None
        self._csql_cell_version = None
        self._time_created = None
        self._time_refreshed = None
        self._cloudera_manager_url = None
        self._ambari_url = None
        self._big_data_manager_url = None
        self._hue_server_url = None

    @property
    def bda_version(self):
        """
        Gets the bda_version of this ClusterDetails.
        BDA version installed in the cluster


        :return: The bda_version of this ClusterDetails.
        :rtype: str
        """
        return self._bda_version

    @bda_version.setter
    def bda_version(self, bda_version):
        """
        Sets the bda_version of this ClusterDetails.
        BDA version installed in the cluster


        :param bda_version: The bda_version of this ClusterDetails.
        :type: str
        """
        self._bda_version = bda_version

    @property
    def bdm_version(self):
        """
        Gets the bdm_version of this ClusterDetails.
        Big Data Manager version installed in the cluster.


        :return: The bdm_version of this ClusterDetails.
        :rtype: str
        """
        return self._bdm_version

    @bdm_version.setter
    def bdm_version(self, bdm_version):
        """
        Sets the bdm_version of this ClusterDetails.
        Big Data Manager version installed in the cluster.


        :param bdm_version: The bdm_version of this ClusterDetails.
        :type: str
        """
        self._bdm_version = bdm_version

    @property
    def bds_version(self):
        """
        Gets the bds_version of this ClusterDetails.
        Big Data Service version installed in the cluster.


        :return: The bds_version of this ClusterDetails.
        :rtype: str
        """
        return self._bds_version

    @bds_version.setter
    def bds_version(self, bds_version):
        """
        Sets the bds_version of this ClusterDetails.
        Big Data Service version installed in the cluster.


        :param bds_version: The bds_version of this ClusterDetails.
        :type: str
        """
        self._bds_version = bds_version

    @property
    def os_version(self):
        """
        Gets the os_version of this ClusterDetails.
        Oracle Linux version installed in the cluster.


        :return: The os_version of this ClusterDetails.
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """
        Sets the os_version of this ClusterDetails.
        Oracle Linux version installed in the cluster.


        :param os_version: The os_version of this ClusterDetails.
        :type: str
        """
        self._os_version = os_version

    @property
    def db_version(self):
        """
        Gets the db_version of this ClusterDetails.
        Cloud SQL query server database version.


        :return: The db_version of this ClusterDetails.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this ClusterDetails.
        Cloud SQL query server database version.


        :param db_version: The db_version of this ClusterDetails.
        :type: str
        """
        self._db_version = db_version

    @property
    def bd_cell_version(self):
        """
        Gets the bd_cell_version of this ClusterDetails.
        Cloud SQL cell version.


        :return: The bd_cell_version of this ClusterDetails.
        :rtype: str
        """
        return self._bd_cell_version

    @bd_cell_version.setter
    def bd_cell_version(self, bd_cell_version):
        """
        Sets the bd_cell_version of this ClusterDetails.
        Cloud SQL cell version.


        :param bd_cell_version: The bd_cell_version of this ClusterDetails.
        :type: str
        """
        self._bd_cell_version = bd_cell_version

    @property
    def csql_cell_version(self):
        """
        Gets the csql_cell_version of this ClusterDetails.
        Big Data SQL version.


        :return: The csql_cell_version of this ClusterDetails.
        :rtype: str
        """
        return self._csql_cell_version

    @csql_cell_version.setter
    def csql_cell_version(self, csql_cell_version):
        """
        Sets the csql_cell_version of this ClusterDetails.
        Big Data SQL version.


        :param csql_cell_version: The csql_cell_version of this ClusterDetails.
        :type: str
        """
        self._csql_cell_version = csql_cell_version

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ClusterDetails.
        The time the cluster was created, shown as an RFC 3339 formatted datetime string.


        :return: The time_created of this ClusterDetails.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ClusterDetails.
        The time the cluster was created, shown as an RFC 3339 formatted datetime string.


        :param time_created: The time_created of this ClusterDetails.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_refreshed(self):
        """
        Gets the time_refreshed of this ClusterDetails.
        The time the cluster was automatically or manually refreshed, shown as an RFC 3339 formatted datetime string.


        :return: The time_refreshed of this ClusterDetails.
        :rtype: datetime
        """
        return self._time_refreshed

    @time_refreshed.setter
    def time_refreshed(self, time_refreshed):
        """
        Sets the time_refreshed of this ClusterDetails.
        The time the cluster was automatically or manually refreshed, shown as an RFC 3339 formatted datetime string.


        :param time_refreshed: The time_refreshed of this ClusterDetails.
        :type: datetime
        """
        self._time_refreshed = time_refreshed

    @property
    def cloudera_manager_url(self):
        """
        Gets the cloudera_manager_url of this ClusterDetails.
        The URL of Cloudera Manager


        :return: The cloudera_manager_url of this ClusterDetails.
        :rtype: str
        """
        return self._cloudera_manager_url

    @cloudera_manager_url.setter
    def cloudera_manager_url(self, cloudera_manager_url):
        """
        Sets the cloudera_manager_url of this ClusterDetails.
        The URL of Cloudera Manager


        :param cloudera_manager_url: The cloudera_manager_url of this ClusterDetails.
        :type: str
        """
        self._cloudera_manager_url = cloudera_manager_url

    @property
    def ambari_url(self):
        """
        Gets the ambari_url of this ClusterDetails.
        The URL of Ambari


        :return: The ambari_url of this ClusterDetails.
        :rtype: str
        """
        return self._ambari_url

    @ambari_url.setter
    def ambari_url(self, ambari_url):
        """
        Sets the ambari_url of this ClusterDetails.
        The URL of Ambari


        :param ambari_url: The ambari_url of this ClusterDetails.
        :type: str
        """
        self._ambari_url = ambari_url

    @property
    def big_data_manager_url(self):
        """
        Gets the big_data_manager_url of this ClusterDetails.
        The URL of Big Data Manager.


        :return: The big_data_manager_url of this ClusterDetails.
        :rtype: str
        """
        return self._big_data_manager_url

    @big_data_manager_url.setter
    def big_data_manager_url(self, big_data_manager_url):
        """
        Sets the big_data_manager_url of this ClusterDetails.
        The URL of Big Data Manager.


        :param big_data_manager_url: The big_data_manager_url of this ClusterDetails.
        :type: str
        """
        self._big_data_manager_url = big_data_manager_url

    @property
    def hue_server_url(self):
        """
        Gets the hue_server_url of this ClusterDetails.
        The URL of the Hue server.


        :return: The hue_server_url of this ClusterDetails.
        :rtype: str
        """
        return self._hue_server_url

    @hue_server_url.setter
    def hue_server_url(self, hue_server_url):
        """
        Sets the hue_server_url of this ClusterDetails.
        The URL of the Hue server.


        :param hue_server_url: The hue_server_url of this ClusterDetails.
        :type: str
        """
        self._hue_server_url = hue_server_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagementAgent(object):
    """
    The details of the Management Agent inventory including the associated plugins.
    """

    #: A constant which can be used with the platform_type property of a ManagementAgent.
    #: This constant has a value of "LINUX"
    PLATFORM_TYPE_LINUX = "LINUX"

    #: A constant which can be used with the platform_type property of a ManagementAgent.
    #: This constant has a value of "WINDOWS"
    PLATFORM_TYPE_WINDOWS = "WINDOWS"

    #: A constant which can be used with the availability_status property of a ManagementAgent.
    #: This constant has a value of "ACTIVE"
    AVAILABILITY_STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the availability_status property of a ManagementAgent.
    #: This constant has a value of "SILENT"
    AVAILABILITY_STATUS_SILENT = "SILENT"

    #: A constant which can be used with the availability_status property of a ManagementAgent.
    #: This constant has a value of "NOT_AVAILABLE"
    AVAILABILITY_STATUS_NOT_AVAILABLE = "NOT_AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgent.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagementAgent object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ManagementAgent.
        :type id: str

        :param install_key_id:
            The value to assign to the install_key_id property of this ManagementAgent.
        :type install_key_id: str

        :param display_name:
            The value to assign to the display_name property of this ManagementAgent.
        :type display_name: str

        :param platform_type:
            The value to assign to the platform_type property of this ManagementAgent.
            Allowed values for this property are: "LINUX", "WINDOWS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type platform_type: str

        :param platform_name:
            The value to assign to the platform_name property of this ManagementAgent.
        :type platform_name: str

        :param platform_version:
            The value to assign to the platform_version property of this ManagementAgent.
        :type platform_version: str

        :param version:
            The value to assign to the version property of this ManagementAgent.
        :type version: str

        :param host:
            The value to assign to the host property of this ManagementAgent.
        :type host: str

        :param host_id:
            The value to assign to the host_id property of this ManagementAgent.
        :type host_id: str

        :param install_path:
            The value to assign to the install_path property of this ManagementAgent.
        :type install_path: str

        :param plugin_list:
            The value to assign to the plugin_list property of this ManagementAgent.
        :type plugin_list: list[oci.management_agent.models.ManagementAgentPluginDetails]

        :param compartment_id:
            The value to assign to the compartment_id property of this ManagementAgent.
        :type compartment_id: str

        :param is_agent_auto_upgradable:
            The value to assign to the is_agent_auto_upgradable property of this ManagementAgent.
        :type is_agent_auto_upgradable: bool

        :param time_created:
            The value to assign to the time_created property of this ManagementAgent.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ManagementAgent.
        :type time_updated: datetime

        :param time_last_heartbeat:
            The value to assign to the time_last_heartbeat property of this ManagementAgent.
        :type time_last_heartbeat: datetime

        :param availability_status:
            The value to assign to the availability_status property of this ManagementAgent.
            Allowed values for this property are: "ACTIVE", "SILENT", "NOT_AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type availability_status: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ManagementAgent.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ManagementAgent.
        :type lifecycle_details: str

        :param is_customer_deployed:
            The value to assign to the is_customer_deployed property of this ManagementAgent.
        :type is_customer_deployed: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ManagementAgent.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ManagementAgent.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'install_key_id': 'str',
            'display_name': 'str',
            'platform_type': 'str',
            'platform_name': 'str',
            'platform_version': 'str',
            'version': 'str',
            'host': 'str',
            'host_id': 'str',
            'install_path': 'str',
            'plugin_list': 'list[ManagementAgentPluginDetails]',
            'compartment_id': 'str',
            'is_agent_auto_upgradable': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'time_last_heartbeat': 'datetime',
            'availability_status': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'is_customer_deployed': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'install_key_id': 'installKeyId',
            'display_name': 'displayName',
            'platform_type': 'platformType',
            'platform_name': 'platformName',
            'platform_version': 'platformVersion',
            'version': 'version',
            'host': 'host',
            'host_id': 'hostId',
            'install_path': 'installPath',
            'plugin_list': 'pluginList',
            'compartment_id': 'compartmentId',
            'is_agent_auto_upgradable': 'isAgentAutoUpgradable',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'time_last_heartbeat': 'timeLastHeartbeat',
            'availability_status': 'availabilityStatus',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'is_customer_deployed': 'isCustomerDeployed',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._install_key_id = None
        self._display_name = None
        self._platform_type = None
        self._platform_name = None
        self._platform_version = None
        self._version = None
        self._host = None
        self._host_id = None
        self._install_path = None
        self._plugin_list = None
        self._compartment_id = None
        self._is_agent_auto_upgradable = None
        self._time_created = None
        self._time_updated = None
        self._time_last_heartbeat = None
        self._availability_status = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._is_customer_deployed = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ManagementAgent.
        agent identifier


        :return: The id of this ManagementAgent.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagementAgent.
        agent identifier


        :param id: The id of this ManagementAgent.
        :type: str
        """
        self._id = id

    @property
    def install_key_id(self):
        """
        Gets the install_key_id of this ManagementAgent.
        agent install key identifier


        :return: The install_key_id of this ManagementAgent.
        :rtype: str
        """
        return self._install_key_id

    @install_key_id.setter
    def install_key_id(self, install_key_id):
        """
        Sets the install_key_id of this ManagementAgent.
        agent install key identifier


        :param install_key_id: The install_key_id of this ManagementAgent.
        :type: str
        """
        self._install_key_id = install_key_id

    @property
    def display_name(self):
        """
        Gets the display_name of this ManagementAgent.
        Management Agent Name


        :return: The display_name of this ManagementAgent.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagementAgent.
        Management Agent Name


        :param display_name: The display_name of this ManagementAgent.
        :type: str
        """
        self._display_name = display_name

    @property
    def platform_type(self):
        """
        Gets the platform_type of this ManagementAgent.
        Platform Type

        Allowed values for this property are: "LINUX", "WINDOWS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The platform_type of this ManagementAgent.
        :rtype: str
        """
        return self._platform_type

    @platform_type.setter
    def platform_type(self, platform_type):
        """
        Sets the platform_type of this ManagementAgent.
        Platform Type


        :param platform_type: The platform_type of this ManagementAgent.
        :type: str
        """
        allowed_values = ["LINUX", "WINDOWS"]
        if not value_allowed_none_or_none_sentinel(platform_type, allowed_values):
            platform_type = 'UNKNOWN_ENUM_VALUE'
        self._platform_type = platform_type

    @property
    def platform_name(self):
        """
        Gets the platform_name of this ManagementAgent.
        Platform Name


        :return: The platform_name of this ManagementAgent.
        :rtype: str
        """
        return self._platform_name

    @platform_name.setter
    def platform_name(self, platform_name):
        """
        Sets the platform_name of this ManagementAgent.
        Platform Name


        :param platform_name: The platform_name of this ManagementAgent.
        :type: str
        """
        self._platform_name = platform_name

    @property
    def platform_version(self):
        """
        Gets the platform_version of this ManagementAgent.
        Platform Version


        :return: The platform_version of this ManagementAgent.
        :rtype: str
        """
        return self._platform_version

    @platform_version.setter
    def platform_version(self, platform_version):
        """
        Sets the platform_version of this ManagementAgent.
        Platform Version


        :param platform_version: The platform_version of this ManagementAgent.
        :type: str
        """
        self._platform_version = platform_version

    @property
    def version(self):
        """
        **[Required]** Gets the version of this ManagementAgent.
        Management Agent Version


        :return: The version of this ManagementAgent.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ManagementAgent.
        Management Agent Version


        :param version: The version of this ManagementAgent.
        :type: str
        """
        self._version = version

    @property
    def host(self):
        """
        Gets the host of this ManagementAgent.
        Management Agent host machine name


        :return: The host of this ManagementAgent.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this ManagementAgent.
        Management Agent host machine name


        :param host: The host of this ManagementAgent.
        :type: str
        """
        self._host = host

    @property
    def host_id(self):
        """
        Gets the host_id of this ManagementAgent.
        Host resource ocid


        :return: The host_id of this ManagementAgent.
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        """
        Sets the host_id of this ManagementAgent.
        Host resource ocid


        :param host_id: The host_id of this ManagementAgent.
        :type: str
        """
        self._host_id = host_id

    @property
    def install_path(self):
        """
        Gets the install_path of this ManagementAgent.
        Path where Management Agent is installed


        :return: The install_path of this ManagementAgent.
        :rtype: str
        """
        return self._install_path

    @install_path.setter
    def install_path(self, install_path):
        """
        Sets the install_path of this ManagementAgent.
        Path where Management Agent is installed


        :param install_path: The install_path of this ManagementAgent.
        :type: str
        """
        self._install_path = install_path

    @property
    def plugin_list(self):
        """
        Gets the plugin_list of this ManagementAgent.
        list of managementAgentPlugins associated with the agent


        :return: The plugin_list of this ManagementAgent.
        :rtype: list[oci.management_agent.models.ManagementAgentPluginDetails]
        """
        return self._plugin_list

    @plugin_list.setter
    def plugin_list(self, plugin_list):
        """
        Sets the plugin_list of this ManagementAgent.
        list of managementAgentPlugins associated with the agent


        :param plugin_list: The plugin_list of this ManagementAgent.
        :type: list[oci.management_agent.models.ManagementAgentPluginDetails]
        """
        self._plugin_list = plugin_list

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ManagementAgent.
        Compartment Identifier


        :return: The compartment_id of this ManagementAgent.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ManagementAgent.
        Compartment Identifier


        :param compartment_id: The compartment_id of this ManagementAgent.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_agent_auto_upgradable(self):
        """
        Gets the is_agent_auto_upgradable of this ManagementAgent.
        true if the agent can be upgraded automatically; false if it must be upgraded manually.


        :return: The is_agent_auto_upgradable of this ManagementAgent.
        :rtype: bool
        """
        return self._is_agent_auto_upgradable

    @is_agent_auto_upgradable.setter
    def is_agent_auto_upgradable(self, is_agent_auto_upgradable):
        """
        Sets the is_agent_auto_upgradable of this ManagementAgent.
        true if the agent can be upgraded automatically; false if it must be upgraded manually.


        :param is_agent_auto_upgradable: The is_agent_auto_upgradable of this ManagementAgent.
        :type: bool
        """
        self._is_agent_auto_upgradable = is_agent_auto_upgradable

    @property
    def time_created(self):
        """
        Gets the time_created of this ManagementAgent.
        The time the Management Agent was created. An RFC3339 formatted datetime string


        :return: The time_created of this ManagementAgent.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ManagementAgent.
        The time the Management Agent was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this ManagementAgent.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ManagementAgent.
        The time the Management Agent was updated. An RFC3339 formatted datetime string


        :return: The time_updated of this ManagementAgent.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ManagementAgent.
        The time the Management Agent was updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this ManagementAgent.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def time_last_heartbeat(self):
        """
        Gets the time_last_heartbeat of this ManagementAgent.
        The time the Management Agent has last recorded its health status in telemetry. This value will be null if the agent has not recorded its health status in last 7 days. An RFC3339 formatted datetime string


        :return: The time_last_heartbeat of this ManagementAgent.
        :rtype: datetime
        """
        return self._time_last_heartbeat

    @time_last_heartbeat.setter
    def time_last_heartbeat(self, time_last_heartbeat):
        """
        Sets the time_last_heartbeat of this ManagementAgent.
        The time the Management Agent has last recorded its health status in telemetry. This value will be null if the agent has not recorded its health status in last 7 days. An RFC3339 formatted datetime string


        :param time_last_heartbeat: The time_last_heartbeat of this ManagementAgent.
        :type: datetime
        """
        self._time_last_heartbeat = time_last_heartbeat

    @property
    def availability_status(self):
        """
        Gets the availability_status of this ManagementAgent.
        The current availability status of managementAgent

        Allowed values for this property are: "ACTIVE", "SILENT", "NOT_AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The availability_status of this ManagementAgent.
        :rtype: str
        """
        return self._availability_status

    @availability_status.setter
    def availability_status(self, availability_status):
        """
        Sets the availability_status of this ManagementAgent.
        The current availability status of managementAgent


        :param availability_status: The availability_status of this ManagementAgent.
        :type: str
        """
        allowed_values = ["ACTIVE", "SILENT", "NOT_AVAILABLE"]
        if not value_allowed_none_or_none_sentinel(availability_status, allowed_values):
            availability_status = 'UNKNOWN_ENUM_VALUE'
        self._availability_status = availability_status

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this ManagementAgent.
        The current state of managementAgent

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ManagementAgent.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ManagementAgent.
        The current state of managementAgent


        :param lifecycle_state: The lifecycle_state of this ManagementAgent.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ManagementAgent.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this ManagementAgent.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ManagementAgent.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this ManagementAgent.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def is_customer_deployed(self):
        """
        Gets the is_customer_deployed of this ManagementAgent.
        true, if the agent image is manually downloaded and installed. false, if the agent is deployed as a plugin in Oracle Cloud Agent.


        :return: The is_customer_deployed of this ManagementAgent.
        :rtype: bool
        """
        return self._is_customer_deployed

    @is_customer_deployed.setter
    def is_customer_deployed(self, is_customer_deployed):
        """
        Sets the is_customer_deployed of this ManagementAgent.
        true, if the agent image is manually downloaded and installed. false, if the agent is deployed as a plugin in Oracle Cloud Agent.


        :param is_customer_deployed: The is_customer_deployed of this ManagementAgent.
        :type: bool
        """
        self._is_customer_deployed = is_customer_deployed

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ManagementAgent.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ManagementAgent.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ManagementAgent.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ManagementAgent.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ManagementAgent.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ManagementAgent.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ManagementAgent.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ManagementAgent.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PingProbeResultSummary(object):
    """
    The results returned by running a ping probe.  All times and durations are
    returned in milliseconds. All times are relative to the POSIX epoch
    (1970-01-01T00:00Z).
    """

    #: A constant which can be used with the error_category property of a PingProbeResultSummary.
    #: This constant has a value of "NONE"
    ERROR_CATEGORY_NONE = "NONE"

    #: A constant which can be used with the error_category property of a PingProbeResultSummary.
    #: This constant has a value of "DNS"
    ERROR_CATEGORY_DNS = "DNS"

    #: A constant which can be used with the error_category property of a PingProbeResultSummary.
    #: This constant has a value of "TRANSPORT"
    ERROR_CATEGORY_TRANSPORT = "TRANSPORT"

    #: A constant which can be used with the error_category property of a PingProbeResultSummary.
    #: This constant has a value of "NETWORK"
    ERROR_CATEGORY_NETWORK = "NETWORK"

    #: A constant which can be used with the error_category property of a PingProbeResultSummary.
    #: This constant has a value of "SYSTEM"
    ERROR_CATEGORY_SYSTEM = "SYSTEM"

    #: A constant which can be used with the protocol property of a PingProbeResultSummary.
    #: This constant has a value of "ICMP"
    PROTOCOL_ICMP = "ICMP"

    #: A constant which can be used with the protocol property of a PingProbeResultSummary.
    #: This constant has a value of "TCP"
    PROTOCOL_TCP = "TCP"

    def __init__(self, **kwargs):
        """
        Initializes a new PingProbeResultSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this PingProbeResultSummary.
        :type key: str

        :param probe_configuration_id:
            The value to assign to the probe_configuration_id property of this PingProbeResultSummary.
        :type probe_configuration_id: str

        :param start_time:
            The value to assign to the start_time property of this PingProbeResultSummary.
        :type start_time: float

        :param target:
            The value to assign to the target property of this PingProbeResultSummary.
        :type target: str

        :param vantage_point_name:
            The value to assign to the vantage_point_name property of this PingProbeResultSummary.
        :type vantage_point_name: str

        :param is_timed_out:
            The value to assign to the is_timed_out property of this PingProbeResultSummary.
        :type is_timed_out: bool

        :param is_healthy:
            The value to assign to the is_healthy property of this PingProbeResultSummary.
        :type is_healthy: bool

        :param error_category:
            The value to assign to the error_category property of this PingProbeResultSummary.
            Allowed values for this property are: "NONE", "DNS", "TRANSPORT", "NETWORK", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type error_category: str

        :param error_message:
            The value to assign to the error_message property of this PingProbeResultSummary.
        :type error_message: str

        :param protocol:
            The value to assign to the protocol property of this PingProbeResultSummary.
            Allowed values for this property are: "ICMP", "TCP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        :param connection:
            The value to assign to the connection property of this PingProbeResultSummary.
        :type connection: oci.healthchecks.models.Connection

        :param dns:
            The value to assign to the dns property of this PingProbeResultSummary.
        :type dns: oci.healthchecks.models.DNS

        :param domain_lookup_start:
            The value to assign to the domain_lookup_start property of this PingProbeResultSummary.
        :type domain_lookup_start: float

        :param domain_lookup_end:
            The value to assign to the domain_lookup_end property of this PingProbeResultSummary.
        :type domain_lookup_end: float

        :param latency_in_ms:
            The value to assign to the latency_in_ms property of this PingProbeResultSummary.
        :type latency_in_ms: float

        :param icmp_code:
            The value to assign to the icmp_code property of this PingProbeResultSummary.
        :type icmp_code: int

        """
        self.swagger_types = {
            'key': 'str',
            'probe_configuration_id': 'str',
            'start_time': 'float',
            'target': 'str',
            'vantage_point_name': 'str',
            'is_timed_out': 'bool',
            'is_healthy': 'bool',
            'error_category': 'str',
            'error_message': 'str',
            'protocol': 'str',
            'connection': 'Connection',
            'dns': 'DNS',
            'domain_lookup_start': 'float',
            'domain_lookup_end': 'float',
            'latency_in_ms': 'float',
            'icmp_code': 'int'
        }

        self.attribute_map = {
            'key': 'key',
            'probe_configuration_id': 'probeConfigurationId',
            'start_time': 'startTime',
            'target': 'target',
            'vantage_point_name': 'vantagePointName',
            'is_timed_out': 'isTimedOut',
            'is_healthy': 'isHealthy',
            'error_category': 'errorCategory',
            'error_message': 'errorMessage',
            'protocol': 'protocol',
            'connection': 'connection',
            'dns': 'dns',
            'domain_lookup_start': 'domainLookupStart',
            'domain_lookup_end': 'domainLookupEnd',
            'latency_in_ms': 'latencyInMs',
            'icmp_code': 'icmpCode'
        }

        self._key = None
        self._probe_configuration_id = None
        self._start_time = None
        self._target = None
        self._vantage_point_name = None
        self._is_timed_out = None
        self._is_healthy = None
        self._error_category = None
        self._error_message = None
        self._protocol = None
        self._connection = None
        self._dns = None
        self._domain_lookup_start = None
        self._domain_lookup_end = None
        self._latency_in_ms = None
        self._icmp_code = None

    @property
    def key(self):
        """
        Gets the key of this PingProbeResultSummary.
        A value identifying this specific probe result. The key is only unique within
        the results of its probe configuration. The key may be reused after 90 days.


        :return: The key of this PingProbeResultSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this PingProbeResultSummary.
        A value identifying this specific probe result. The key is only unique within
        the results of its probe configuration. The key may be reused after 90 days.


        :param key: The key of this PingProbeResultSummary.
        :type: str
        """
        self._key = key

    @property
    def probe_configuration_id(self):
        """
        Gets the probe_configuration_id of this PingProbeResultSummary.
        The OCID of the monitor or on-demand probe responsible for creating this result.


        :return: The probe_configuration_id of this PingProbeResultSummary.
        :rtype: str
        """
        return self._probe_configuration_id

    @probe_configuration_id.setter
    def probe_configuration_id(self, probe_configuration_id):
        """
        Sets the probe_configuration_id of this PingProbeResultSummary.
        The OCID of the monitor or on-demand probe responsible for creating this result.


        :param probe_configuration_id: The probe_configuration_id of this PingProbeResultSummary.
        :type: str
        """
        self._probe_configuration_id = probe_configuration_id

    @property
    def start_time(self):
        """
        Gets the start_time of this PingProbeResultSummary.
        The date and time the probe was executed, expressed in milliseconds since the
        POSIX epoch. This field is defined by the PerformanceResourceTiming interface
        of the W3C Resource Timing specification. For more information, see
        `Resource Timing`__.

        __ https://w3c.github.io/resource-timing/#sec-resource-timing


        :return: The start_time of this PingProbeResultSummary.
        :rtype: float
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this PingProbeResultSummary.
        The date and time the probe was executed, expressed in milliseconds since the
        POSIX epoch. This field is defined by the PerformanceResourceTiming interface
        of the W3C Resource Timing specification. For more information, see
        `Resource Timing`__.

        __ https://w3c.github.io/resource-timing/#sec-resource-timing


        :param start_time: The start_time of this PingProbeResultSummary.
        :type: float
        """
        self._start_time = start_time

    @property
    def target(self):
        """
        Gets the target of this PingProbeResultSummary.
        The target hostname or IP address of the probe.


        :return: The target of this PingProbeResultSummary.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this PingProbeResultSummary.
        The target hostname or IP address of the probe.


        :param target: The target of this PingProbeResultSummary.
        :type: str
        """
        self._target = target

    @property
    def vantage_point_name(self):
        """
        Gets the vantage_point_name of this PingProbeResultSummary.
        The name of the vantage point that executed the probe.


        :return: The vantage_point_name of this PingProbeResultSummary.
        :rtype: str
        """
        return self._vantage_point_name

    @vantage_point_name.setter
    def vantage_point_name(self, vantage_point_name):
        """
        Sets the vantage_point_name of this PingProbeResultSummary.
        The name of the vantage point that executed the probe.


        :param vantage_point_name: The vantage_point_name of this PingProbeResultSummary.
        :type: str
        """
        self._vantage_point_name = vantage_point_name

    @property
    def is_timed_out(self):
        """
        Gets the is_timed_out of this PingProbeResultSummary.
        True if the probe did not complete before the configured `timeoutInSeconds` value.


        :return: The is_timed_out of this PingProbeResultSummary.
        :rtype: bool
        """
        return self._is_timed_out

    @is_timed_out.setter
    def is_timed_out(self, is_timed_out):
        """
        Sets the is_timed_out of this PingProbeResultSummary.
        True if the probe did not complete before the configured `timeoutInSeconds` value.


        :param is_timed_out: The is_timed_out of this PingProbeResultSummary.
        :type: bool
        """
        self._is_timed_out = is_timed_out

    @property
    def is_healthy(self):
        """
        Gets the is_healthy of this PingProbeResultSummary.
        True if the probe result is determined to be healthy based on probe
        type-specific criteria.  For HTTP probes, a probe result is considered
        healthy if the HTTP response code is greater than or equal to 200 and
        less than 300.


        :return: The is_healthy of this PingProbeResultSummary.
        :rtype: bool
        """
        return self._is_healthy

    @is_healthy.setter
    def is_healthy(self, is_healthy):
        """
        Sets the is_healthy of this PingProbeResultSummary.
        True if the probe result is determined to be healthy based on probe
        type-specific criteria.  For HTTP probes, a probe result is considered
        healthy if the HTTP response code is greater than or equal to 200 and
        less than 300.


        :param is_healthy: The is_healthy of this PingProbeResultSummary.
        :type: bool
        """
        self._is_healthy = is_healthy

    @property
    def error_category(self):
        """
        Gets the error_category of this PingProbeResultSummary.
        The category of error if an error occurs executing the probe.
        The `errorMessage` field provides a message with the error details.
        * NONE - No error
        * DNS - DNS errors
        * TRANSPORT - Transport-related errors, for example a \"TLS certificate expired\" error.
        * NETWORK - Network-related errors, for example a \"network unreachable\" error.
        * SYSTEM - Internal system errors.

        Allowed values for this property are: "NONE", "DNS", "TRANSPORT", "NETWORK", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The error_category of this PingProbeResultSummary.
        :rtype: str
        """
        return self._error_category

    @error_category.setter
    def error_category(self, error_category):
        """
        Sets the error_category of this PingProbeResultSummary.
        The category of error if an error occurs executing the probe.
        The `errorMessage` field provides a message with the error details.
        * NONE - No error
        * DNS - DNS errors
        * TRANSPORT - Transport-related errors, for example a \"TLS certificate expired\" error.
        * NETWORK - Network-related errors, for example a \"network unreachable\" error.
        * SYSTEM - Internal system errors.


        :param error_category: The error_category of this PingProbeResultSummary.
        :type: str
        """
        allowed_values = ["NONE", "DNS", "TRANSPORT", "NETWORK", "SYSTEM"]
        if not value_allowed_none_or_none_sentinel(error_category, allowed_values):
            error_category = 'UNKNOWN_ENUM_VALUE'
        self._error_category = error_category

    @property
    def error_message(self):
        """
        Gets the error_message of this PingProbeResultSummary.
        The error information indicating why a probe execution failed.


        :return: The error_message of this PingProbeResultSummary.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this PingProbeResultSummary.
        The error information indicating why a probe execution failed.


        :param error_message: The error_message of this PingProbeResultSummary.
        :type: str
        """
        self._error_message = error_message

    @property
    def protocol(self):
        """
        Gets the protocol of this PingProbeResultSummary.
        Allowed values for this property are: "ICMP", "TCP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this PingProbeResultSummary.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this PingProbeResultSummary.

        :param protocol: The protocol of this PingProbeResultSummary.
        :type: str
        """
        allowed_values = ["ICMP", "TCP"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    @property
    def connection(self):
        """
        Gets the connection of this PingProbeResultSummary.

        :return: The connection of this PingProbeResultSummary.
        :rtype: oci.healthchecks.models.Connection
        """
        return self._connection

    @connection.setter
    def connection(self, connection):
        """
        Sets the connection of this PingProbeResultSummary.

        :param connection: The connection of this PingProbeResultSummary.
        :type: oci.healthchecks.models.Connection
        """
        self._connection = connection

    @property
    def dns(self):
        """
        Gets the dns of this PingProbeResultSummary.

        :return: The dns of this PingProbeResultSummary.
        :rtype: oci.healthchecks.models.DNS
        """
        return self._dns

    @dns.setter
    def dns(self, dns):
        """
        Sets the dns of this PingProbeResultSummary.

        :param dns: The dns of this PingProbeResultSummary.
        :type: oci.healthchecks.models.DNS
        """
        self._dns = dns

    @property
    def domain_lookup_start(self):
        """
        Gets the domain_lookup_start of this PingProbeResultSummary.
        The time immediately before the vantage point starts the domain name lookup for
        the resource.


        :return: The domain_lookup_start of this PingProbeResultSummary.
        :rtype: float
        """
        return self._domain_lookup_start

    @domain_lookup_start.setter
    def domain_lookup_start(self, domain_lookup_start):
        """
        Sets the domain_lookup_start of this PingProbeResultSummary.
        The time immediately before the vantage point starts the domain name lookup for
        the resource.


        :param domain_lookup_start: The domain_lookup_start of this PingProbeResultSummary.
        :type: float
        """
        self._domain_lookup_start = domain_lookup_start

    @property
    def domain_lookup_end(self):
        """
        Gets the domain_lookup_end of this PingProbeResultSummary.
        The time immediately before the vantage point finishes the domain name lookup for
        the resource.


        :return: The domain_lookup_end of this PingProbeResultSummary.
        :rtype: float
        """
        return self._domain_lookup_end

    @domain_lookup_end.setter
    def domain_lookup_end(self, domain_lookup_end):
        """
        Sets the domain_lookup_end of this PingProbeResultSummary.
        The time immediately before the vantage point finishes the domain name lookup for
        the resource.


        :param domain_lookup_end: The domain_lookup_end of this PingProbeResultSummary.
        :type: float
        """
        self._domain_lookup_end = domain_lookup_end

    @property
    def latency_in_ms(self):
        """
        Gets the latency_in_ms of this PingProbeResultSummary.
        The latency of the probe execution, in milliseconds.


        :return: The latency_in_ms of this PingProbeResultSummary.
        :rtype: float
        """
        return self._latency_in_ms

    @latency_in_ms.setter
    def latency_in_ms(self, latency_in_ms):
        """
        Sets the latency_in_ms of this PingProbeResultSummary.
        The latency of the probe execution, in milliseconds.


        :param latency_in_ms: The latency_in_ms of this PingProbeResultSummary.
        :type: float
        """
        self._latency_in_ms = latency_in_ms

    @property
    def icmp_code(self):
        """
        Gets the icmp_code of this PingProbeResultSummary.
        The ICMP code of the response message.  This field is not used when the protocol
        is set to TCP.  For more information on ICMP codes, see
        `Internet Control Message Protocol (ICMP) Parameters`__.

        __ https://www.iana.org/assignments/icmp-parameters/icmp-parameters.xhtml


        :return: The icmp_code of this PingProbeResultSummary.
        :rtype: int
        """
        return self._icmp_code

    @icmp_code.setter
    def icmp_code(self, icmp_code):
        """
        Sets the icmp_code of this PingProbeResultSummary.
        The ICMP code of the response message.  This field is not used when the protocol
        is set to TCP.  For more information on ICMP codes, see
        `Internet Control Message Protocol (ICMP) Parameters`__.

        __ https://www.iana.org/assignments/icmp-parameters/icmp-parameters.xhtml


        :param icmp_code: The icmp_code of this PingProbeResultSummary.
        :type: int
        """
        self._icmp_code = icmp_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
